@@ -336,3 +336,13 @@ def serialize(model, data, fields=None, exc: Optional[set] = None, rels=None, ro
     for element in data:
         resp.append(process(element))
     return resp
+
+
+def json(data):
+    resp = None
+
+    if isinstance(data, list):
+        resp = []
+    for item in data:
+        resp.append(extract(item))
+    return resp
