@@ -5,7 +5,7 @@ from flask import current_app
 from flask_sqlalchemy import BaseQuery
 from sqlalchemy.ext.declarative import DeclarativeMeta
 
-from flask_atomic.orm.base import DeclarativeBase
+# from flask_atomic.orm.base import DeclarativeBase
 from sqlalchemy.exc import InvalidRequestError
 from sqlalchemy.orm import load_only
 from sqlalchemy import desc
@@ -230,7 +230,8 @@ class QueryBuffer:
         query = self.basequery.filter_by(**filter_expression)
         self.data = query.first()
         if not self.data:
-            raise HTTPNotFound(f'{str(self.model.__dict__.get("__tablename__")).capitalize()} not found!')
+            pass
+            # raise HTTPNotFound(f'{str(self.model.__dict__.get("__tablename__")).capitalize()} not found!')
         for item in set([str(i.key) for i in relationships(self.model)]).intersection(self.queryargs.include):
             _item = item
             if not isinstance(_item, str):
